Installation
============

The Python library is available on PyPi, and can be installed by:

.. code-block:: bash

   pip install genpot

The code can also be installed from source by cloning the GitHub repo:

.. code-block:: bash

   git clone https://github.com/evenmn/generate-potential-files.git
   cd generate-potential-files
   pip install .

The library requires Python version >= Python 3.5 since f-strings are used. 
